@@ -33,7 +33,7 @@ def build_graph ():
     rx_decim  = 32
     
     fg = gr.flow_graph ()
-    usrp_rx = usrp1.source_s (0, rx_decim, 1, 0x32103210, usrp1.FPGA_MODE_COUNTING)
+    usrp_rx = usrp.source_s (0, rx_decim, 1, 0x32103210, usrp.FPGA_MODE_COUNTING)
     sink = gr.check_counting_s ()
     fg.connect (usrp_rx, sink)
 
@@ -44,9 +44,10 @@ def build_graph ():
     
 def main ():
     fg = build_graph ()
-    fg.start ()
-    raw_input ('Press Enter to quit: ')
-    fg.stop ()
+    try:
+        fg.run()
+    except KeyboardInterrupt:
+        pass
 
 if __name__ == '__main__':
     main ()
